Developer documentation
=======================

.. toctree::
   :numbered:

   codebase/index
   documentation/index
   tests/index
   scripts/index
   abjad_book/index
   timing/index
   profiling/index
   memory/index
   class_attributes/index
   slots/index
   coding_standards/index
